@@ -332,17 +332,18 @@ class UniqueConstraint(BaseConstraint):
                                 return
                     elif isinstance(expression, F) and expression.name in exclude:
                         return
-            replacement_map = instance._get_field_value_map(
-                meta=model._meta, exclude=exclude
-            )
+            replacements = {
+                F(field): value
+                for field, value in instance._get_field_value_map(
+                    meta=model._meta, exclude=exclude
+                ).items()
+            }
             expressions = []
             for expr in self.expressions:
                 # Ignore ordering.
                 if isinstance(expr, OrderBy):
                     expr = expr.expression
-                expressions.append(
-                    Exact(expr, expr.replace_references(replacement_map))
-                )
+                expressions.append(Exact(expr, expr.replace_expressions(replacements)))
             queryset = queryset.filter(*expressions)
         model_class_pk = instance._get_pk_val(model._meta)
         if not instance._state.adding and model_class_pk is not None:
