@@ -1,10 +1,9 @@
 import uuid
-
-from django.utils import lru_cache
+from functools import lru_cache
 
 
 class IntConverter:
-    regex = '[0-9]+'
+    regex = "[0-9]+"
 
     def to_python(self, value):
         return int(value)
@@ -14,7 +13,7 @@ class IntConverter:
 
 
 class StringConverter:
-    regex = '[^/]+'
+    regex = "[^/]+"
 
     def to_python(self, value):
         return value
@@ -24,7 +23,7 @@ class StringConverter:
 
 
 class UUIDConverter:
-    regex = '[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}'
+    regex = "[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}"
 
     def to_python(self, value):
         return uuid.UUID(value)
@@ -34,19 +33,19 @@ class UUIDConverter:
 
 
 class SlugConverter(StringConverter):
-    regex = '[-a-zA-Z0-9_]+'
+    regex = "[-a-zA-Z0-9_]+"
 
 
 class PathConverter(StringConverter):
-    regex = '.+'
+    regex = ".+"
 
 
 DEFAULT_CONVERTERS = {
-    'int': IntConverter(),
-    'path': PathConverter(),
-    'slug': SlugConverter(),
-    'str': StringConverter(),
-    'uuid': UUIDConverter(),
+    "int": IntConverter(),
+    "path": PathConverter(),
+    "slug": SlugConverter(),
+    "str": StringConverter(),
+    "uuid": UUIDConverter(),
 }
 
 
@@ -58,12 +57,9 @@ def register_converter(converter, type_name):
     get_converters.cache_clear()
 
 
-@lru_cache.lru_cache(maxsize=None)
+@lru_cache(maxsize=None)
 def get_converters():
-    converters = {}
-    converters.update(DEFAULT_CONVERTERS)
-    converters.update(REGISTERED_CONVERTERS)
-    return converters
+    return {**DEFAULT_CONVERTERS, **REGISTERED_CONVERTERS}
 
 
 def get_converter(raw_converter):
